"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    dataset_group_arn: str,
    perform_hpo: bool = None,
    perform_auto_ml: bool = None,
    recipe_arn: str = None,
    event_type: str = None,
    solution_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the configuration for training a model. A trained model is known as a solution. After the configuration is created, you train the model (create a solution) by calling the CreateSolutionVersion operation. Every time you call CreateSolutionVersion, a new version of the solution is created. After creating a solution version, you check its accuracy by calling GetSolutionMetrics. When you are satisfied with the version, you deploy it using CreateCampaign. The campaign provides recommendations to a client through the GetRecommendations API. To train a model, Amazon Personalize requires training data and a recipe. The training data comes from the dataset group that you provide in the request. A recipe specifies the training algorithm and a feature transformation. You can specify one of the predefined recipes provided by Amazon Personalize. Alternatively, you can specify performAutoML and Amazon Personalize will analyze your data and select the optimum USER_PERSONALIZATION recipe for you.  Amazon Personalize doesn't support configuring the hpoObjective for solution hyperparameter optimization at this time.   Status  A solution can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED   DELETE PENDING > DELETE IN_PROGRESS   To get the status of the solution, call DescribeSolution. Wait until the status shows as ACTIVE before calling CreateSolutionVersion.  Related APIs     ListSolutions     CreateSolutionVersion     DescribeSolution     DeleteSolution       ListSolutionVersions     DescribeSolutionVersion

    Args:
        name(str): The name for the solution.
        perform_hpo(bool, optional): Whether to perform hyperparameter optimization (HPO) on the specified or selected recipe. The default is false. When performing AutoML, this parameter is always true and you should not set it to false. Defaults to None.
        perform_auto_ml(bool, optional): Whether to perform automated machine learning (AutoML). The default is false. For this case, you must specify recipeArn. When set to true, Amazon Personalize analyzes your training data and selects the optimal USER_PERSONALIZATION recipe and hyperparameters. In this case, you must omit recipeArn. Amazon Personalize determines the optimal recipe by running tests with different values for the hyperparameters. AutoML lengthens the training process as compared to selecting a specific recipe. Defaults to None.
        recipe_arn(str, optional): The ARN of the recipe to use for model training. Only specified when performAutoML is false. Defaults to None.
        dataset_group_arn(str): The Amazon Resource Name (ARN) of the dataset group that provides the training data.
        event_type(str, optional): When your have multiple event types (using an EVENT_TYPE schema field), this parameter specifies which event type (for example, 'click' or 'like') is used for training the model. If you do not provide an eventType, Amazon Personalize will use all interactions for training with equal weight regardless of type. Defaults to None.
        solution_config(Dict, optional): The configuration to use with the solution. When performAutoML is set to true, Amazon Personalize only evaluates the autoMLConfig section of the solution configuration.  Amazon Personalize doesn't support configuring the hpoObjective at this time. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.init.create(
                ctx, name=value, dataset_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.init.create name=value, dataset_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_solution",
        op_kwargs={
            "name": name,
            "performHPO": perform_hpo,
            "performAutoML": perform_auto_ml,
            "recipeArn": recipe_arn,
            "datasetGroupArn": dataset_group_arn,
            "eventType": event_type,
            "solutionConfig": solution_config,
        },
    )


async def delete(hub, ctx, solution_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes all versions of a solution and the Solution object itself. Before deleting a solution, you must delete all campaigns based on the solution. To determine what campaigns are using the solution, call ListCampaigns and supply the Amazon Resource Name (ARN) of the solution. You can't delete a solution if an associated SolutionVersion is in the CREATE PENDING or IN PROGRESS state. For more information on solutions, see CreateSolution.

    Args:
        solution_arn(str): The ARN of the solution to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.init.delete(ctx, solution_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.init.delete solution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="delete_solution",
        op_kwargs={"solutionArn": solution_arn},
    )


async def describe(hub, ctx, solution_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a solution. For more information on solutions, see CreateSolution.

    Args:
        solution_arn(str): The Amazon Resource Name (ARN) of the solution to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.init.describe(ctx, solution_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.init.describe solution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_solution",
        op_kwargs={"solutionArn": solution_arn},
    )


async def list_all(
    hub,
    ctx,
    dataset_group_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of solutions that use the given dataset group. When a dataset group is not specified, all the solutions associated with the account are listed. The response provides the properties for each solution, including the Amazon Resource Name (ARN). For more information on solutions, see CreateSolution.

    Args:
        dataset_group_arn(str, optional): The Amazon Resource Name (ARN) of the dataset group. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListSolutions for getting the next set of solutions (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of solutions to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_solutions",
        op_kwargs={
            "datasetGroupArn": dataset_group_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, account_id: str, user_id: str, e164_phone_number: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a phone number with the specified Amazon Chime user.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.
        e164_phone_number(str): The phone number, in E.164 format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.with_.user.associate(
                ctx, account_id=value, user_id=value, e164_phone_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.with_.user.associate account_id=value, user_id=value, e164_phone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="associate_phone_number_with_user",
        op_kwargs={
            "AccountId": account_id,
            "UserId": user_id,
            "E164PhoneNumber": e164_phone_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"open_": "open"}


async def close(hub, ctx, port_info: Dict, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Closes ports for a specific Amazon Lightsail instance. The CloseInstancePublicPorts action supports tag-based access control via resource tags applied to the resource identified by instanceName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        port_info(Dict): An object to describe the ports to close for the specified instance.
        instance_name(str): The name of the instance for which to close ports.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.public_port.close(
                ctx, port_info=value, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.public_port.close port_info=value, instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="close_instance_public_ports",
        op_kwargs={"portInfo": port_info, "instanceName": instance_name},
    )


async def open_(hub, ctx, port_info: Dict, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Opens ports for a specific Amazon Lightsail instance, and specifies the IP addresses allowed to connect to the instance through the ports, and the protocol. The OpenInstancePublicPorts action supports tag-based access control via resource tags applied to the resource identified by instanceName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        port_info(Dict): An object to describe the ports to open for the specified instance.
        instance_name(str): The name of the instance for which to open ports.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.public_port.open(
                ctx, port_info=value, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.public_port.open port_info=value, instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="open_instance_public_ports",
        op_kwargs={"portInfo": port_info, "instanceName": instance_name},
    )


async def put_multiple(hub, ctx, port_infos: List, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Opens ports for a specific Amazon Lightsail instance, and specifies the IP addresses allowed to connect to the instance through the ports, and the protocol. This action also closes all currently open ports that are not included in the request. Include all of the ports and the protocols you want to open in your PutInstancePublicPortsrequest. Or use the OpenInstancePublicPorts action to open ports without closing currently open ports. The PutInstancePublicPorts action supports tag-based access control via resource tags applied to the resource identified by instanceName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        port_infos(List): An array of objects to describe the ports to open for the specified instance.
        instance_name(str): The name of the instance for which to open ports.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.public_port.put_multiple(
                ctx, port_infos=value, instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.public_port.put_multiple port_infos=value, instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="put_instance_public_ports",
        op_kwargs={"portInfos": port_infos, "instanceName": instance_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, configuration_set_name: str, delivery_options: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates the delivery options for a configuration set.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to specify the delivery options for.
        delivery_options(Dict, optional): Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.delivery_option.put_multiple(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.delivery_option.put_multiple configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="put_configuration_set_delivery_options",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "DeliveryOptions": delivery_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, job_id: str) -> None:
    r"""
    **Autogenerated function**

    This operation cancels a job. Jobs can be cancelled only when they are in the WAITING state.

    Args:
        job_id(str): The unique identifier for a job.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.job.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.job.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="cancel_job",
        op_kwargs={"JobId": job_id},
    )


async def create(hub, ctx, details: Dict, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation creates a job.

    Args:
        details(Dict): The details for the CreateJob request.
        type_(str): The type of job to be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.job.create(ctx, details=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.job.create details=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="create_job",
        op_kwargs={"Details": details, "Type": type_},
    )


async def get(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns information about a job.

    Args:
        job_id(str): The unique identifier for a job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.job.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.job.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="get_job",
        op_kwargs={"JobId": job_id},
    )


async def start(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation starts a job.

    Args:
        job_id(str): The unique identifier for a job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dataexchange.job.start(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dataexchange.job.start job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dataexchange",
        operation="start_job",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    destination_phone_number: str,
    contact_flow_id: str,
    instance_id: str,
    client_token: str = None,
    source_phone_number: str = None,
    queue_id: str = None,
    attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Places an outbound call to a contact, and then initiates the contact flow. It performs the actions in the contact flow that's specified (in ContactFlowId). Agents do not initiate the outbound API, which means that they do not dial the contact. If the contact flow places an outbound call to a contact, and then puts the contact in queue, the call is then routed to the agent, like any other inbound case. There is a 60-second dialing timeout for this operation. If the call is not connected after 60 seconds, it fails.  UK numbers with a 447 prefix are not allowed by default. Before you can dial these UK mobile numbers, you must submit a service quota increase request. For more information, see Amazon Connect Service Quotas in the Amazon Connect Administrator Guide.

    Args:
        destination_phone_number(str): The phone number of the customer, in E.164 format.
        contact_flow_id(str): The identifier of the contact flow for the outbound call. To see the ContactFlowId in the Amazon Connect console user interface, on the navigation menu go to Routing, Contact Flows. Choose the contact flow. On the contact flow page, under the name of the contact flow, choose Show additional flow information. The ContactFlowId is the last part of the ARN, shown here in bold:  arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx .
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. The token is valid for 7 days after creation. If a contact is already started, the contact ID is returned. . Defaults to None.
        source_phone_number(str, optional): The phone number associated with the Amazon Connect instance, in E.164 format. If you do not specify a source phone number, you must specify a queue. Defaults to None.
        queue_id(str, optional): The queue for the call. If you specify a queue, the phone displayed for caller ID is the phone number specified in the queue. If you do not specify a queue, the queue defined in the contact flow is used. If you do not specify a queue, you must specify a source phone number. Defaults to None.
        attributes(Dict, optional): A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in contact flows just like any other contact attributes. There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.outbound_voice_contact.start(
                ctx, destination_phone_number=value, contact_flow_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.outbound_voice_contact.start destination_phone_number=value, contact_flow_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="start_outbound_voice_contact",
        op_kwargs={
            "DestinationPhoneNumber": destination_phone_number,
            "ContactFlowId": contact_flow_id,
            "InstanceId": instance_id,
            "ClientToken": client_token,
            "SourcePhoneNumber": source_phone_number,
            "QueueId": queue_id,
            "Attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    execution_arn: str,
    max_results: int = None,
    reverse_order: bool = None,
    next_token: str = None,
    include_execution_data: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the history of the specified execution as a list of events. By default, the results are returned in ascending order of the timeStamp of the events. Use the reverseOrder parameter to get the latest events first. If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error. This API action is not supported by EXPRESS state machines.

    Args:
        execution_arn(str): The Amazon Resource Name (ARN) of the execution.
        max_results(int, optional): The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default. This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum. Defaults to None.
        reverse_order(bool, optional): Lists events in descending order of their timeStamp. Defaults to None.
        next_token(str, optional): If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error. Defaults to None.
        include_execution_data(bool, optional): You can select whether execution data (input or output of a history event) is returned. The default is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.execution.history.get(ctx, execution_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.execution.history.get execution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="get_execution_history",
        op_kwargs={
            "executionArn": execution_arn,
            "maxResults": max_results,
            "reverseOrder": reverse_order,
            "nextToken": next_token,
            "includeExecutionData": include_execution_data,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def delete(hub, ctx, account_id: str, vault_name: str) -> None:
    r"""
    **Autogenerated function**

    This operation deletes the access policy associated with the specified vault. The operation is eventually consistent; that is, it might take some time for Amazon S3 Glacier to completely remove the access policy, and you might still see the effect of the policy for a short time after you send the delete request. This operation is idempotent. You can invoke delete multiple times, even if there is no policy associated with the vault. For more information about vault access policies, see Amazon Glacier Access Control with Vault Access Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.access_policy.delete(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.access_policy.delete account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="delete_vault_access_policy",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def get(hub, ctx, account_id: str, vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation retrieves the access-policy subresource set on the vault; for more information on setting this subresource, see Set Vault Access Policy (PUT access-policy). If there is no access policy set on the vault, the operation returns a 404 Not found error. For more information about vault access policies, see Amazon Glacier Access Control with Vault Access Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.access_policy.get(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.access_policy.get account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="get_vault_access_policy",
        op_kwargs={"accountId": account_id, "vaultName": vault_name},
    )


async def set_(hub, ctx, account_id: str, vault_name: str, policy: Dict = None) -> None:
    r"""
    **Autogenerated function**

    This operation configures an access policy for a vault and will overwrite an existing policy. To configure a vault access policy, send a PUT request to the access-policy subresource of the vault. An access policy is specific to a vault and is also called a vault subresource. You can set one access policy per vault and the policy can be up to 20 KB in size. For more information about vault access policies, see Amazon Glacier Access Control with Vault Access Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        policy(Dict, optional): The vault access policy as a JSON string. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.vault.access_policy.set(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.vault.access_policy.set account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="set_vault_access_policy",
        op_kwargs={"accountId": account_id, "vaultName": vault_name, "policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    db_user: str,
    cluster_identifier: str,
    db_name: str = None,
    duration_seconds: int = None,
    auto_create: bool = None,
    db_groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a database user name and temporary password with temporary authorization to log on to an Amazon Redshift database. The action returns the database user name prefixed with IAM: if AutoCreate is False or IAMA: if AutoCreate is True. You can optionally specify one or more database user groups that the user will join at log on. By default, the temporary credentials expire in 900 seconds. You can optionally specify a duration between 900 seconds (15 minutes) and 3600 seconds (60 minutes). For more information, see Using IAM Authentication to Generate Database User Credentials in the Amazon Redshift Cluster Management Guide. The Identity and Access Management (IAM) user or role that runs GetClusterCredentials must have an IAM policy attached that allows access to all necessary actions and resources. For more information about permissions, see Resource Policies for GetClusterCredentials in the Amazon Redshift Cluster Management Guide. If the DbGroups parameter is specified, the IAM policy must allow the redshift:JoinGroup action with access to the listed dbgroups.  In addition, if the AutoCreate parameter is set to True, then the policy must include the redshift:CreateClusterUser privilege. If the DbName parameter is specified, the IAM policy must allow access to the resource dbname for the specified database name.

    Args:
        db_user(str): The name of a database user. If a user name matching DbUser exists in the database, the temporary user credentials have the same permissions as the existing user. If DbUser doesn't exist in the database and Autocreate is True, a new user is created using the value for DbUser with PUBLIC permissions. If a database user matching the value for DbUser doesn't exist and Autocreate is False, then the command succeeds but the connection attempt will fail because the user doesn't exist in the database. For more information, see CREATE USER in the Amazon Redshift Database Developer Guide.  Constraints:   Must be 1 to 64 alphanumeric characters or hyphens. The user name can't be PUBLIC.   Must contain only lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.   First character must be a letter.   Must not contain a colon ( : ) or slash ( / ).    Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.  .
        db_name(str, optional): The name of a database that DbUser is authorized to log on to. If DbName is not specified, DbUser can log on to any existing database. Constraints:   Must be 1 to 64 alphanumeric characters or hyphens   Must contain only lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.   First character must be a letter.   Must not contain a colon ( : ) or slash ( / ).    Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.  . Defaults to None.
        cluster_identifier(str): The unique identifier of the cluster that contains the database for which your are requesting credentials. This parameter is case sensitive.
        duration_seconds(int, optional): The number of seconds until the returned temporary password expires. Constraint: minimum 900, maximum 3600. Default: 900. Defaults to None.
        auto_create(bool, optional): Create a database user with the name specified for the user named in DbUser if one does not exist. Defaults to None.
        db_groups(List, optional): A list of the names of existing database groups that the user named in DbUser will join for the current session, in addition to any group memberships for an existing user. If not specified, a new user is added only to PUBLIC. Database group name constraints   Must be 1 to 64 alphanumeric characters or hyphens   Must contain only lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.   First character must be a letter.   Must not contain a colon ( : ) or slash ( / ).    Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.credential.get_all(
                ctx, db_user=value, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.credential.get_all db_user=value, cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="get_cluster_credentials",
        op_kwargs={
            "DbUser": db_user,
            "DbName": db_name,
            "ClusterIdentifier": cluster_identifier,
            "DurationSeconds": duration_seconds,
            "AutoCreate": auto_create,
            "DbGroups": db_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    source_identifier: str = None,
    source_type: str = None,
    start_time: str = None,
    end_time: str = None,
    duration: int = None,
    event_categories: List = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns events related to DB instances, DB clusters, DB parameter groups, DB security groups, DB snapshots, and DB cluster snapshots for the past 14 days. Events specific to a particular DB instances, DB clusters, DB parameter groups, DB security groups, DB snapshots, and DB cluster snapshots group can be obtained by providing the name as a parameter.  By default, the past hour of events are returned.

    Args:
        source_identifier(str, optional): The identifier of the event source for which events are returned. If not specified, then all sources are included in the response. Constraints:   If SourceIdentifier is supplied, SourceType must also be provided.   If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.   If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.   If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.   If the source type is a DB security group, a DBSecurityGroupName value must be supplied.   If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.   If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.   Can't end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        source_type(str, optional): The event source to retrieve events for. If no value is specified, all events are returned. Defaults to None.
        start_time(str, optional):  The beginning of the time interval to retrieve events for, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.  Example: 2009-07-08T18:00Z. Defaults to None.
        end_time(str, optional):  The end of the time interval for which to retrieve events, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.  Example: 2009-07-08T18:00Z. Defaults to None.
        duration(int, optional): The number of minutes to retrieve events for. Default: 60. Defaults to None.
        event_categories(List, optional): A list of event categories that trigger notifications for a event notification subscription. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeEvents request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_events",
        op_kwargs={
            "SourceIdentifier": source_identifier,
            "SourceType": source_type,
            "StartTime": start_time,
            "EndTime": end_time,
            "Duration": duration,
            "EventCategories": event_categories,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    lo_ra_wan: Dict,
    name: str = None,
    description: str = None,
    tags: List = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a wireless gateway.

    Args:
        name(str, optional): The name of the new resource. Defaults to None.
        description(str, optional): The description of the new resource. Defaults to None.
        lo_ra_wan(Dict): The gateway configuration information to use to create the wireless gateway.
        tags(List, optional): The tags to attach to the new wireless gateway. Tags are metadata that you can use to manage a resource. Defaults to None.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.init.create(ctx, lo_ra_wan=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.init.create lo_ra_wan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_wireless_gateway",
        op_kwargs={
            "Name": name,
            "Description": description,
            "LoRaWAN": lo_ra_wan,
            "Tags": tags,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a wireless gateway.

    Args:
        id_(str): The ID of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_wireless_gateway",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, identifier: str, identifier_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a wireless gateway.

    Args:
        identifier(str): The identifier of the wireless gateway to get.
        identifier_type(str): The type of identifier used in identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.init.get(
                ctx, identifier=value, identifier_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.init.get identifier=value, identifier_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_gateway",
        op_kwargs={"Identifier": identifier, "IdentifierType": identifier_type},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the wireless gateways registered to your AWS account.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_wireless_gateways",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    id_: str,
    name: str = None,
    description: str = None,
    join_eui_filters: List = None,
    net_id_filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties of a wireless gateway.

    Args:
        id_(str): The ID of the resource to update.
        name(str, optional): The new name of the resource. Defaults to None.
        description(str, optional): A new description of the resource. Defaults to None.
        join_eui_filters(List, optional): A list of JoinEuiRange used by LoRa gateways to filter LoRa frames. Defaults to None.
        net_id_filters(List, optional): A list of NetId values that are used by LoRa gateways to filter the uplink frames. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="update_wireless_gateway",
        op_kwargs={
            "Id": id_,
            "Name": name,
            "Description": description,
            "JoinEuiFilters": join_eui_filters,
            "NetIdFilters": net_id_filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(
    hub,
    ctx,
    directory_id: str,
    ip_routes: List,
    update_security_group_for_directory_controllers: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    If the DNS server for your on-premises domain uses a publicly addressable IP address, you must add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services. AddIpRoutes adds this address block. You can also use AddIpRoutes to facilitate routing traffic that uses public IP ranges from your Microsoft AD on AWS to a peer VPC.  Before you call AddIpRoutes, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the AddIpRoutes operation, see AWS Directory Service API Permissions: Actions, Resources, and Conditions Reference.

    Args:
        directory_id(str): Identifier (ID) of the directory to which to add the address block.
        ip_routes(List): IP address blocks, using CIDR format, of the traffic to route. This is often the IP address block of the DNS server used for your on-premises domain.
        update_security_group_for_directory_controllers(bool, optional): If set to true, updates the inbound and outbound rules of the security group that has the description: "AWS created security group for directory ID directory controllers." Following are the new rules:  Inbound:   Type: Custom UDP Rule, Protocol: UDP, Range: 88, Source: 0.0.0.0/0   Type: Custom UDP Rule, Protocol: UDP, Range: 123, Source: 0.0.0.0/0   Type: Custom UDP Rule, Protocol: UDP, Range: 138, Source: 0.0.0.0/0   Type: Custom UDP Rule, Protocol: UDP, Range: 389, Source: 0.0.0.0/0   Type: Custom UDP Rule, Protocol: UDP, Range: 464, Source: 0.0.0.0/0   Type: Custom UDP Rule, Protocol: UDP, Range: 445, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 88, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 135, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 445, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 464, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 636, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 1024-65535, Source: 0.0.0.0/0   Type: Custom TCP Rule, Protocol: TCP, Range: 3268-33269, Source: 0.0.0.0/0   Type: DNS (UDP), Protocol: UDP, Range: 53, Source: 0.0.0.0/0   Type: DNS (TCP), Protocol: TCP, Range: 53, Source: 0.0.0.0/0   Type: LDAP, Protocol: TCP, Range: 389, Source: 0.0.0.0/0   Type: All ICMP, Protocol: All, Range: N/A, Source: 0.0.0.0/0    Outbound:   Type: All traffic, Protocol: All, Range: All, Destination: 0.0.0.0/0   These security rules impact an internal network interface that is not exposed publicly. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.ip_route.add(ctx, directory_id=value, ip_routes=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.ip_route.add directory_id=value, ip_routes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="add_ip_routes",
        op_kwargs={
            "DirectoryId": directory_id,
            "IpRoutes": ip_routes,
            "UpdateSecurityGroupForDirectoryControllers": update_security_group_for_directory_controllers,
        },
    )


async def list_all(
    hub, ctx, directory_id: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the address blocks that you have added to a directory.

    Args:
        directory_id(str): Identifier (ID) of the directory for which you want to retrieve the IP addresses.
        next_token(str, optional): The ListIpRoutes.NextToken value from a previous call to ListIpRoutes. Pass null if this is the first call. Defaults to None.
        limit(int, optional): Maximum number of items to return. If this value is zero, the maximum number of items is specified by the limitations of the operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.ip_route.list_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.ip_route.list_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="list_ip_routes",
        op_kwargs={
            "DirectoryId": directory_id,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def remove(hub, ctx, directory_id: str, cidr_ips: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes IP address blocks from a directory.

    Args:
        directory_id(str): Identifier (ID) of the directory from which you want to remove the IP addresses.
        cidr_ips(List): IP address blocks that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.ip_route.remove(ctx, directory_id=value, cidr_ips=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.ip_route.remove directory_id=value, cidr_ips=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="remove_ip_routes",
        op_kwargs={"DirectoryId": directory_id, "CidrIps": cidr_ips},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.setting.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.setting.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="chime", operation="get_phone_number_settings", op_kwargs={}
    )


async def update_multiple(hub, ctx, calling_name: str) -> None:
    r"""
    **Autogenerated function**

    Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.

    Args:
        calling_name(str): The default outbound calling name for the account.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.setting.update_multiple(
                ctx, calling_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.setting.update_multiple calling_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_phone_number_settings",
        op_kwargs={"CallingName": calling_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, bot_name: str, bot_alias: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes session information for a specified bot, alias, and user ID.

    Args:
        bot_name(str): The name of the bot that contains the session data.
        bot_alias(str): The alias in use for the bot that contains the session data.
        user_id(str): The identifier of the user associated with the session data.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_runtime.session.delete(
                ctx, bot_name=value, bot_alias=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_runtime.session.delete bot_name=value, bot_alias=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-runtime",
        operation="delete_session",
        op_kwargs={"botName": bot_name, "botAlias": bot_alias, "userId": user_id},
    )


async def get(
    hub,
    ctx,
    bot_name: str,
    bot_alias: str,
    user_id: str,
    checkpoint_label_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns session information for a specified bot, alias, and user ID.

    Args:
        bot_name(str): The name of the bot that contains the session data.
        bot_alias(str): The alias in use for the bot that contains the session data.
        user_id(str): The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. .
        checkpoint_label_filter(str, optional): A string used to filter the intents returned in the recentIntentSummaryView structure.  When you specify a filter, only intents with their checkpointLabel field set to that string are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_runtime.session.get(
                ctx, bot_name=value, bot_alias=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_runtime.session.get bot_name=value, bot_alias=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-runtime",
        operation="get_session",
        op_kwargs={
            "botName": bot_name,
            "botAlias": bot_alias,
            "userId": user_id,
            "checkpointLabelFilter": checkpoint_label_filter,
        },
    )


async def put(
    hub,
    ctx,
    bot_name: str,
    bot_alias: str,
    user_id: str,
    session_attributes: Dict = None,
    dialog_action: Dict = None,
    recent_intent_summary_view: List = None,
    accept: str = None,
    active_contexts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new session or modifies an existing session with an Amazon Lex bot. Use this operation to enable your application to set the state of the bot. For more information, see Managing Sessions.

    Args:
        bot_name(str): The name of the bot that contains the session data.
        bot_alias(str): The alias in use for the bot that contains the session data.
        user_id(str): The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. .
        session_attributes(Dict, optional): Map of key/value pairs representing the session-specific context information. It contains application information passed between Amazon Lex and a client application. Defaults to None.
        dialog_action(Dict, optional): Sets the next action that the bot should take to fulfill the conversation. Defaults to None.
        recent_intent_summary_view(List, optional): A summary of the recent intents for the bot. You can use the intent summary view to set a checkpoint label on an intent and modify attributes of intents. You can also use it to remove or add intent summary objects to the list. An intent that you modify or add to the list must make sense for the bot. For example, the intent name must be valid for the bot. You must provide valid values for:    intentName    slot names    slotToElict    If you send the recentIntentSummaryView parameter in a PutSession request, the contents of the new summary view replaces the old summary view. For example, if a GetSession request returns three intents in the summary view and you call PutSession with one intent in the summary view, the next call to GetSession will only return one intent. Defaults to None.
        accept(str, optional): The message that Amazon Lex returns in the response can be either text or speech based depending on the value of this field.   If the value is text/plain; charset=utf-8, Amazon Lex returns text in the response.   If the value begins with audio/, Amazon Lex returns speech in the response. Amazon Lex uses Amazon Polly to generate the speech in the configuration that you specify. For example, if you specify audio/mpeg as the value, Amazon Lex returns speech in the MPEG format.   If the value is audio/pcm, the speech is returned as audio/pcm in 16-bit, little endian format.   The following are the accepted values:    audio/mpeg     audio/ogg     audio/pcm     audio/* (defaults to mpeg)    text/plain; charset=utf-8     . Defaults to None.
        active_contexts(List, optional): A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request, If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_runtime.session.put(
                ctx, bot_name=value, bot_alias=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_runtime.session.put bot_name=value, bot_alias=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-runtime",
        operation="put_session",
        op_kwargs={
            "botName": bot_name,
            "botAlias": bot_alias,
            "userId": user_id,
            "sessionAttributes": session_attributes,
            "dialogAction": dialog_action,
            "recentIntentSummaryView": recent_intent_summary_view,
            "accept": accept,
            "activeContexts": active_contexts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, virtual_interface_id: str, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a virtual interface with a specified link aggregation group (LAG) or connection. Connectivity to Amazon Web Services is temporarily interrupted as the virtual interface is being migrated. If the target connection or LAG has an associated virtual interface with a conflicting VLAN number or a conflicting IP address, the operation fails. Virtual interfaces associated with a hosted connection cannot be associated with a LAG; hosted connections must be migrated along with their virtual interfaces using AssociateHostedConnection. To reassociate a virtual interface to a new connection or LAG, the requester must own either the virtual interface itself or the connection to which the virtual interface is currently associated. Additionally, the requester must own the connection or LAG for the association.

    Args:
        virtual_interface_id(str): The ID of the virtual interface.
        connection_id(str): The ID of the LAG or connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.virtual.interface.init.associate(
                ctx, virtual_interface_id=value, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.virtual.interface.init.associate virtual_interface_id=value, connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="associate_virtual_interface",
        op_kwargs={
            "virtualInterfaceId": virtual_interface_id,
            "connectionId": connection_id,
        },
    )


async def delete(hub, ctx, virtual_interface_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a virtual interface.

    Args:
        virtual_interface_id(str): The ID of the virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.virtual.interface.init.delete(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.virtual.interface.init.delete virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_virtual_interface",
        op_kwargs={"virtualInterfaceId": virtual_interface_id},
    )


async def describe_all(
    hub, ctx, connection_id: str = None, virtual_interface_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Displays all virtual interfaces for an account. Virtual interfaces deleted fewer than 15 minutes before you make the request are also returned. If you specify a connection ID, only the virtual interfaces associated with the connection are returned. If you specify a virtual interface ID, then only a single virtual interface is returned. A virtual interface (VLAN) transmits the traffic between the Direct Connect location and the customer network.

    Args:
        connection_id(str, optional): The ID of the connection. Defaults to None.
        virtual_interface_id(str, optional): The ID of the virtual interface. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.virtual.interface.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.virtual.interface.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_virtual_interfaces",
        op_kwargs={
            "connectionId": connection_id,
            "virtualInterfaceId": virtual_interface_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(
    hub,
    ctx,
    hosted_zone_id: str,
    record_name: str,
    record_type: str,
    resolver_ip: str = None,
    edns0_client_subnet_ip: str = None,
    edns0_client_subnet_mask: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the value that Amazon Route 53 returns in response to a DNS request for a specified record name and type. You can optionally specify the IP address of a DNS resolver, an EDNS0 client subnet IP address, and a subnet mask.  This call only supports querying public hosted zones.

    Args:
        hosted_zone_id(str): The ID of the hosted zone that you want Amazon Route 53 to simulate a query for.
        record_name(str): The name of the resource record set that you want Amazon Route 53 to simulate a query for.
        record_type(str): The type of the resource record set.
        resolver_ip(str, optional): If you want to simulate a request from a specific DNS resolver, specify the IP address for that resolver. If you omit this value, TestDnsAnswer uses the IP address of a DNS resolver in the Amazon Web Services US East (N. Virginia) Region (us-east-1). Defaults to None.
        edns0_client_subnet_ip(str, optional): If the resolver that you specified for resolverip supports EDNS0, specify the IPv4 or IPv6 address of a client in the applicable location, for example, 192.0.2.44 or 2001:db8:85a3::8a2e:370:7334. Defaults to None.
        edns0_client_subnet_mask(str, optional): If you specify an IP address for edns0clientsubnetip, you can optionally specify the number of bits of the IP address that you want the checking tool to include in the DNS query. For example, if you specify 192.0.2.44 for edns0clientsubnetip and 24 for edns0clientsubnetmask, the checking tool will simulate a request from 192.0.2.0/24. The default value is 24 bits for IPv4 addresses and 64 bits for IPv6 addresses. The range of valid values depends on whether edns0clientsubnetip is an IPv4 or an IPv6 address:    IPv4: Specify a value between 0 and 32    IPv6: Specify a value between 0 and 128  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.dns.answer.test(
                ctx, hosted_zone_id=value, record_name=value, record_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.dns.answer.test hosted_zone_id=value, record_name=value, record_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="test_dns_answer",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "RecordName": record_name,
            "RecordType": record_type,
            "ResolverIP": resolver_ip,
            "EDNS0ClientSubnetIP": edns0_client_subnet_ip,
            "EDNS0ClientSubnetMask": edns0_client_subnet_mask,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def confirm(
    hub,
    ctx,
    access_token: str,
    device_key: str,
    device_secret_verifier_config: Dict = None,
    device_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Confirms tracking of the device. This API call is the call that begins device tracking.

    Args:
        access_token(str): The access token.
        device_key(str): The device key.
        device_secret_verifier_config(Dict, optional): The configuration of the device secret verifier. Defaults to None.
        device_name(str, optional): The device name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.device.init.confirm(
                ctx, access_token=value, device_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.device.init.confirm access_token=value, device_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="confirm_device",
        op_kwargs={
            "AccessToken": access_token,
            "DeviceKey": device_key,
            "DeviceSecretVerifierConfig": device_secret_verifier_config,
            "DeviceName": device_name,
        },
    )


async def forget(hub, ctx, device_key: str, access_token: str = None) -> None:
    r"""
    **Autogenerated function**

    Forgets the specified device.

    Args:
        access_token(str, optional): The access token for the forgotten device request. Defaults to None.
        device_key(str): The device key.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.device.init.forget(ctx, device_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.device.init.forget device_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="forget_device",
        op_kwargs={"AccessToken": access_token, "DeviceKey": device_key},
    )


async def get(hub, ctx, device_key: str, access_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the device.

    Args:
        device_key(str): The device key.
        access_token(str, optional): The access token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.device.init.get(ctx, device_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.device.init.get device_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="get_device",
        op_kwargs={"DeviceKey": device_key, "AccessToken": access_token},
    )


async def list_all(
    hub, ctx, access_token: str, limit: int = None, pagination_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the devices.

    Args:
        access_token(str): The access tokens for the request to list devices.
        limit(int, optional): The limit of the device request. Defaults to None.
        pagination_token(str, optional): The pagination token for the list request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.device.init.list_all(ctx, access_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.device.init.list_all access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_devices",
        op_kwargs={
            "AccessToken": access_token,
            "Limit": limit,
            "PaginationToken": pagination_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, definition: Dict, compatible_namespace_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a workflow template. Workflows can be created only in the user's namespace. (The public namespace contains only entities.) The workflow can contain only entities in the specified namespace. The workflow is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.

    Args:
        definition(Dict): The workflow DefinitionDocument.
        compatible_namespace_version(int, optional): The namespace version in which the workflow is to be created. If no value is specified, the latest version is used by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.create(ctx, definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.create definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="create_flow_template",
        op_kwargs={
            "definition": definition,
            "compatibleNamespaceVersion": compatible_namespace_version,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a workflow. Any new system or deployment that contains this workflow will fail to update or deploy. Existing deployments that contain the workflow will continue to run (since they use a snapshot of the workflow taken at the time of deployment).

    Args:
        id_(str): The ID of the workflow to be deleted. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="delete_flow_template",
        op_kwargs={"id": id_},
    )


async def deprecate(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deprecates the specified workflow. This action marks the workflow for deletion. Deprecated flows can't be deployed, but existing deployments will continue to run.

    Args:
        id_(str): The ID of the workflow to be deleted. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.deprecate(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.deprecate id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="deprecate_flow_template",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str, revision_number: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the latest version of the DefinitionDocument and FlowTemplateSummary for the specified workflow.

    Args:
        id_(str): The ID of the workflow. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME .
        revision_number(int, optional): The number of the workflow revision to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_flow_template",
        op_kwargs={"id": id_, "revisionNumber": revision_number},
    )


async def search(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for summary information about workflows.

    Args:
        filters(List, optional): An array of objects that limit the result set. The only valid filter is DEVICE_MODEL_ID. Defaults to None.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="search_flow_templates",
        op_kwargs={
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, id_: str, definition: Dict, compatible_namespace_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified workflow. All deployed systems and system instances that use the workflow will see the changes in the flow when it is redeployed. If you don't want this behavior, copy the workflow (creating a new workflow with a different ID), and update the copy. The workflow can contain only entities in the specified namespace.

    Args:
        id_(str): The ID of the workflow to be updated. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:workflow:WORKFLOWNAME .
        definition(Dict): The DefinitionDocument that contains the updated workflow definition.
        compatible_namespace_version(int, optional): The version of the user's namespace. If no value is specified, the latest version is used by default. Use the GetFlowTemplateRevisions if you want to find earlier revisions of the flow to update. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.template.init.update(
                ctx, id_=value, definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.template.init.update id_=value, definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="update_flow_template",
        op_kwargs={
            "id": id_,
            "definition": definition,
            "compatibleNamespaceVersion": compatible_namespace_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, request_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified quota increase request.

    Args:
        request_id(str): The ID of the quota increase request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.requested_service_quota_change.init.get(
                ctx, request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.requested_service_quota_change.init.get request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="get_requested_service_quota_change",
        op_kwargs={"RequestId": request_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, resource_name: str, bucket_name: str, access: str) -> Dict:
    r"""
    **Autogenerated function**

    Sets the Amazon Lightsail resources that can access the specified Lightsail bucket. Lightsail buckets currently support setting access for Lightsail instances in the same AWS Region.

    Args:
        resource_name(str): The name of the Lightsail instance for which to set bucket access. The instance must be in a running or stopped state.
        bucket_name(str): The name of the bucket for which to set access to another Lightsail resource.
        access(str): The access setting. The following access settings are available:    allow - Allows access to the bucket and its objects.    deny - Denies access to the bucket and its objects. Use this setting to remove access for a resource previously set to allow.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.resource.access_for_bucket.set(
                ctx, resource_name=value, bucket_name=value, access=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.resource.access_for_bucket.set resource_name=value, bucket_name=value, access=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="set_resource_access_for_bucket",
        op_kwargs={
            "resourceName": resource_name,
            "bucketName": bucket_name,
            "access": access,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub,
    ctx,
    reserved_instance_ids: List,
    dry_run: bool = None,
    target_configurations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts the Convertible Reserved Instance exchange quote described in the GetReservedInstancesExchangeQuote call.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        reserved_instance_ids(List): The IDs of the Convertible Reserved Instances to exchange for another Convertible Reserved Instance of the same or higher value.
        target_configurations(List, optional): The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.exchange_quote.accept(
                ctx, reserved_instance_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.exchange_quote.accept reserved_instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="accept_reserved_instances_exchange_quote",
        op_kwargs={
            "DryRun": dry_run,
            "ReservedInstanceIds": reserved_instance_ids,
            "TargetConfigurations": target_configurations,
        },
    )


async def get(
    hub,
    ctx,
    reserved_instance_ids: List,
    dry_run: bool = None,
    target_configurations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a quote and exchange information for exchanging one or more specified Convertible Reserved Instances for a new Convertible Reserved Instance. If the exchange cannot be performed, the reason is returned in the response. Use AcceptReservedInstancesExchangeQuote to perform the exchange.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        reserved_instance_ids(List): The IDs of the Convertible Reserved Instances to exchange.
        target_configurations(List, optional): The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.reserved_instance.exchange_quote.get(
                ctx, reserved_instance_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.reserved_instance.exchange_quote.get reserved_instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_reserved_instances_exchange_quote",
        op_kwargs={
            "DryRun": dry_run,
            "ReservedInstanceIds": reserved_instance_ids,
            "TargetConfigurations": target_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, load_balancer_name: str, instance_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Attaches one or more Lightsail instances to a load balancer. After some time, the instances are attached to the load balancer and the health check status is available. The attach instances to load balancer operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        instance_names(List): An array of strings representing the instance name(s) you want to attach to your load balancer. An instance must be running before you can attach it to your load balancer. There are no additional limits on the number of instances you can attach to your load balancer, aside from the limit of Lightsail instances you can create in your account (20).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.to_load_balancer.attach(
                ctx, load_balancer_name=value, instance_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.to_load_balancer.attach load_balancer_name=value, instance_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="attach_instances_to_load_balancer",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "instanceNames": instance_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, service_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Return a list of operations that occurred on an AWS App Runner service. The resulting list of OperationSummary objects is sorted in reverse chronological order. The first object on the list represents the last started operation.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want a list of operations for.
        next_token(str, optional): A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones specified in the initial request. If you don't specify NextToken, the request retrieves the first result page. Defaults to None.
        max_results(int, optional): The maximum number of results to include in each response (result page). It's used for a paginated request. If you don't specify MaxResults, the request retrieves all available results in a single response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.operation.list_all(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.operation.list_all service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="list_operations",
        op_kwargs={
            "ServiceArn": service_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, secret_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables automatic scheduled rotation and cancels the rotation of a secret if currently in progress. To re-enable scheduled rotation, call RotateSecret with AutomaticallyRotateAfterDays set to a value greater than 0. This immediately rotates your secret and then enables the automatic schedule.  If you cancel a rotation while in progress, it can leave the VersionStage labels in an unexpected state. Depending on the step of the rotation in progress, you might need to remove the staging label AWSPENDING from the partially created version, specified by the VersionId response value. You should also evaluate the partially rotated new version to see if it should be deleted, which you can do by removing all staging labels from the new version VersionStage field.  To successfully start a rotation, the staging label AWSPENDING must be in one of the following states:   Not attached to any version at all   Attached to the same version as the staging label AWSCURRENT    If the staging label AWSPENDING attached to a different version than the version with AWSCURRENT then the attempt to rotate fails.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:CancelRotateSecret    Related operations    To configure rotation for a secret or to manually trigger a rotation, use RotateSecret.   To get the rotation configuration details for a secret, use DescribeSecret.   To list all of the currently available secrets, use ListSecrets.   To list all of the versions currently associated with a secret, use ListSecretVersionIds.

    Args:
        secret_id(str): Specifies the secret to cancel a rotation request. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.rotate_secret.cancel(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.rotate_secret.cancel secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="cancel_rotate_secret",
        op_kwargs={"SecretId": secret_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    authorization_type: str,
    auth_parameters: Dict,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a connection. A connection defines the authorization type and credentials to use for authorization with an API destination HTTP endpoint.

    Args:
        name(str): The name for the connection to create.
        description(str, optional): A description for the connection to create. Defaults to None.
        authorization_type(str): The type of authorization to use for the connection.
        auth_parameters(Dict): A CreateConnectionAuthRequestParameters object that contains the authorization parameters to use to authorize with the endpoint. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.create(
                ctx, name=value, authorization_type=value, auth_parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.create name=value, authorization_type=value, auth_parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="create_connection",
        op_kwargs={
            "Name": name,
            "Description": description,
            "AuthorizationType": authorization_type,
            "AuthParameters": auth_parameters,
        },
    )


async def deauthorize(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes all authorization parameters from the connection. This lets you remove the secret from the connection so you can reuse it without having to create a new connection.

    Args:
        name(str): The name of the connection to remove authorization from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.deauthorize(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.deauthorize name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="deauthorize_connection",
        op_kwargs={"Name": name},
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a connection.

    Args:
        name(str): The name of the connection to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_connection",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details about a connection.

    Args:
        name(str): The name of the connection to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_connection",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub,
    ctx,
    name_prefix: str = None,
    connection_state: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of connections from the account.

    Args:
        name_prefix(str, optional): A name prefix to filter results returned. Only connections with a name that starts with the prefix are returned. Defaults to None.
        connection_state(str, optional): The state of the connection. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of connections to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_connections",
        op_kwargs={
            "NamePrefix": name_prefix,
            "ConnectionState": connection_state,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    authorization_type: str = None,
    auth_parameters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates settings for a connection.

    Args:
        name(str): The name of the connection to update.
        description(str, optional): A description for the connection. Defaults to None.
        authorization_type(str, optional): The type of authorization to use for the connection. Defaults to None.
        auth_parameters(Dict, optional): The authorization parameters to use for the connection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.connection.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.connection.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="update_connection",
        op_kwargs={
            "Name": name,
            "Description": description,
            "AuthorizationType": authorization_type,
            "AuthParameters": auth_parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(
    hub, ctx, db_cluster_identifier: str, role_arn: str, feature_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Disassociates an Amazon Web Services Identity and Access Management (IAM) role from an Amazon Aurora DB cluster. For more information, see Authorizing Amazon Aurora MySQL to Access Other Amazon Web Services Services on Your Behalf  in the Amazon Aurora User Guide.  This action only applies to Aurora DB clusters.

    Args:
        db_cluster_identifier(str): The name of the DB cluster to disassociate the IAM role from.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role to disassociate from the Aurora DB cluster, for example arn:aws:iam::123456789012:role/AuroraAccessRole.
        feature_name(str, optional): The name of the feature for the DB cluster that the IAM role is to be disassociated from. For the list of supported feature names, see DBEngineVersion. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.role.from_db.cluster.remove(
                ctx, db_cluster_identifier=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.role.from_db.cluster.remove db_cluster_identifier=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="remove_role_from_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "RoleArn": role_arn,
            "FeatureName": feature_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, function_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes the code signing configuration from the function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.code.signing_config.delete(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.code.signing_config.delete function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_function_code_signing_config",
        op_kwargs={"FunctionName": function_name},
    )


async def get(hub, ctx, function_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the code signing configuration for the specified function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.code.signing_config.get(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.code.signing_config.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_function_code_signing_config",
        op_kwargs={"FunctionName": function_name},
    )


async def put(hub, ctx, code_signing_config_arn: str, function_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Update the code signing configuration for the function. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.

    Args:
        code_signing_config_arn(str): The The Amazon Resource Name (ARN) of the code signing configuration.
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.code.signing_config.put(
                ctx, code_signing_config_arn=value, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.code.signing_config.put code_signing_config_arn=value, function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="put_function_code_signing_config",
        op_kwargs={
            "CodeSigningConfigArn": code_signing_config_arn,
            "FunctionName": function_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, domain: str, domain_owner: str = None, duration_seconds: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Generates a temporary authorization token for accessing repositories in the domain. This API requires the codeartifact:GetAuthorizationToken and sts:GetServiceBearerToken permissions. For more information about authorization tokens, see AWS CodeArtifact authentication and tokens.   CodeArtifact authorization tokens are valid for a period of 12 hours when created with the login command. You can call login periodically to refresh the token. When you create an authorization token with the GetAuthorizationToken API, you can set a custom authorization period, up to a maximum of 12 hours, with the durationSeconds parameter. The authorization period begins after login or GetAuthorizationToken is called. If login or GetAuthorizationToken is called while assuming a role, the token lifetime is independent of the maximum session duration of the role. For example, if you call sts assume-role and specify a session duration of 15 minutes, then generate a CodeArtifact authorization token, the token will be valid for the full authorization period even though this is longer than the 15-minute session duration. See Using IAM Roles for more information on controlling session duration.

    Args:
        domain(str):  The name of the domain that is in scope for the generated authorization token. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        duration_seconds(int, optional): The time, in seconds, that the generated authorization token is valid. Valid values are 0 and any number between 900 (15 minutes) and 43200 (12 hours). A value of 0 will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.authorization_token.get(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.authorization_token.get domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="get_authorization_token",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "durationSeconds": duration_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
    locale: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about events that meet the specified filter criteria. Events are returned in a summary form and do not include the detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the DescribeEventDetails and DescribeAffectedEntities operations. If no filter criteria are specified, all events are returned. Results are sorted by lastModifiedTime, starting with the most recent event.    When you call the DescribeEvents operation and specify an entity for the entityValues parameter, AWS Health might return public events that aren't specific to that resource. For example, if you call DescribeEvents and specify an ID for an Amazon Elastic Compute Cloud (Amazon EC2) instance, AWS Health might return events that aren't specific to that resource or service. To get events that are specific to a service, use the services parameter in the filter object. For more information, see Event.   This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.

    Args:
        filter_(Dict, optional): Values to narrow the results returned. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_events",
        op_kwargs={
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
            "locale": locale,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def poll(hub, ctx, action_type_id: Dict, max_batch_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Determines whether there are any third party jobs for a job worker to act on. Used for partner actions only.  When this API is called, AWS CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts.

    Args:
        action_type_id(Dict): Represents information about an action type.
        max_batch_size(int, optional): The maximum number of jobs to return in a poll for jobs call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.for_.third_party_job.poll(
                ctx, action_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.for_.third_party_job.poll action_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="poll_for_third_party_jobs",
        op_kwargs={"actionTypeId": action_type_id, "maxBatchSize": max_batch_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the account configuration options associated with an Amazon Web Services account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.account_configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.account_configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="acm", operation="get_account_configuration", op_kwargs={}
    )


async def put(hub, ctx, idempotency_token: str, expiry_events: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Adds or modifies account-level configurations in ACM.  The supported configuration option is DaysBeforeExpiry. This option specifies the number of days prior to certificate expiration when ACM starts generating EventBridge events. ACM sends one event per day per certificate until the certificate expires. By default, accounts receive events starting 45 days before certificate expiration.

    Args:
        expiry_events(Dict, optional): Specifies expiration events associated with an account. Defaults to None.
        idempotency_token(str): Customer-chosen string used to distinguish between calls to PutAccountConfiguration. Idempotency tokens time out after one hour. If you call PutAccountConfiguration multiple times with the same unexpired idempotency token, ACM treats it as the same request and returns the original result. If you change the idempotency token for each call, ACM treats each call as a new request.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.account_configuration.put(ctx, idempotency_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.account_configuration.put idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="put_account_configuration",
        op_kwargs={
            "ExpiryEvents": expiry_events,
            "IdempotencyToken": idempotency_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    data_share_arn: str,
    associate_entire_account: bool = None,
    consumer_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    From a datashare consumer account, associates a datashare with the account (AssociateEntireAccount) or the specified namespace (ConsumerArn). If you make this association, the consumer can consume the datashare.

    Args:
        data_share_arn(str): The Amazon Resource Name (ARN) of the datashare that the consumer is to use with the account or the namespace.
        associate_entire_account(bool, optional): A value that specifies whether the datashare is associated with the entire account. Defaults to None.
        consumer_arn(str, optional): The Amazon Resource Name (ARN) of the consumer that is associated with the datashare. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.consumer.associate(
                ctx, data_share_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.consumer.associate data_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="associate_data_share_consumer",
        op_kwargs={
            "DataShareArn": data_share_arn,
            "AssociateEntireAccount": associate_entire_account,
            "ConsumerArn": consumer_arn,
        },
    )


async def disassociate(
    hub,
    ctx,
    data_share_arn: str,
    disassociate_entire_account: bool = None,
    consumer_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    From a consumer account, remove association for the specified datashare.

    Args:
        data_share_arn(str): The Amazon Resource Name (ARN) of the datashare to remove association for. .
        disassociate_entire_account(bool, optional): A value that specifies whether association for the datashare is removed from the entire account. Defaults to None.
        consumer_arn(str, optional): The Amazon Resource Name (ARN) of the consumer that association for the datashare is removed from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.consumer.disassociate(
                ctx, data_share_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.consumer.disassociate data_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="disassociate_data_share_consumer",
        op_kwargs={
            "DataShareArn": data_share_arn,
            "DisassociateEntireAccount": disassociate_entire_account,
            "ConsumerArn": consumer_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    distribution_id: str,
    alias: str,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of aliases (also called CNAMEs or alternate domain names) that conflict or overlap with the provided alias, and the associated CloudFront distributions and Amazon Web Services accounts for each conflicting alias. In the returned list, the distribution and account IDs are partially hidden, which allows you to identify the distributions and accounts that you own, but helps to protect the information of ones that you don’t own. Use this operation to find aliases that are in use in CloudFront that conflict or overlap with the provided alias. For example, if you provide www.example.com as input, the returned list can include www.example.com and the overlapping wildcard alternate domain name (*.example.com), if they exist. If you provide *.example.com as input, the returned list can include *.example.com and any alternate domain names covered by that wildcard (for example, www.example.com, test.example.com, dev.example.com, and so on), if they exist. To list conflicting aliases, you provide the alias to search and the ID of a distribution in your account that has an attached SSL/TLS certificate that includes the provided alias. For more information, including how to set up the distribution and certificate, see Moving an alternate domain name to a different distribution in the Amazon CloudFront Developer Guide. You can optionally specify the maximum number of items to receive in the response. If the total number of items in the list exceeds the maximum that you specify, or the default maximum, the response is paginated. To get the next page of items, send a subsequent request that specifies the NextMarker value from the current response as the Marker value in the subsequent request.

    Args:
        distribution_id(str): The ID of a distribution in your account that has an attached SSL/TLS certificate that includes the provided alias.
        alias(str): The alias (also called a CNAME) to search for conflicting aliases.
        marker(str, optional): Use this field when paginating results to indicate where to begin in the list of conflicting aliases. The response includes conflicting aliases in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response. Defaults to None.
        max_items(int, optional): The maximum number of conflicting aliases that you want in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.conflicting_aliase.list_all(
                ctx, distribution_id=value, alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.conflicting_aliase.list_all distribution_id=value, alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_conflicting_aliases",
        op_kwargs={
            "DistributionId": distribution_id,
            "Alias": alias,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(
    hub, ctx, number_of_bytes: int = None, custom_key_store_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a random byte string that is cryptographically secure. By default, the random byte string is generated in AWS KMS. To generate the byte string in the AWS CloudHSM cluster that is associated with a custom key store, specify the custom key store ID. For more information about entropy and random number generation, see AWS Key Management Service Cryptographic Details.  Required permissions: kms:GenerateRandom (IAM policy)

    Args:
        number_of_bytes(int, optional): The length of the byte string. Defaults to None.
        custom_key_store_id(str, optional): Generates the random byte string in the AWS CloudHSM cluster that is associated with the specified custom key store. To find the ID of a custom key store, use the DescribeCustomKeyStores operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.random.generate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.random.generate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="generate_random",
        op_kwargs={
            "NumberOfBytes": number_of_bytes,
            "CustomKeyStoreId": custom_key_store_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def sample(
    hub,
    ctx,
    channel_name: str,
    max_messages: int = None,
    start_time: str = None,
    end_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a sample of messages from the specified channel ingested during the specified timeframe. Up to 10 messages can be retrieved.

    Args:
        channel_name(str): The name of the channel whose message samples are retrieved.
        max_messages(int, optional): The number of sample messages to be retrieved. The limit is 10. The default is also 10. Defaults to None.
        start_time(str, optional): The start of the time window from which sample messages are retrieved. Defaults to None.
        end_time(str, optional): The end of the time window from which sample messages are retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.data.sample(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.data.sample channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="sample_channel_data",
        op_kwargs={
            "channelName": channel_name,
            "maxMessages": max_messages,
            "startTime": start_time,
            "endTime": end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, certificate_id: str, force_delete: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified certificate. A certificate cannot be deleted if it has a policy or IoT thing attached to it or if its status is set to ACTIVE. To delete a certificate, first use the DetachPrincipalPolicy API to detach all policies. Next, use the UpdateCertificate API to set the certificate to the INACTIVE status.

    Args:
        certificate_id(str): The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.).
        force_delete(bool, optional): Forces the deletion of a certificate if it is inactive and is not attached to an IoT thing. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.delete(ctx, certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.delete certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_certificate",
        op_kwargs={"certificateId": certificate_id, "forceDelete": force_delete},
    )


async def describe(hub, ctx, certificate_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified certificate.

    Args:
        certificate_id(str): The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.describe(ctx, certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.describe certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_certificate",
        op_kwargs={"certificateId": certificate_id},
    )


async def list_all(
    hub, ctx, page_size: int = None, marker: str = None, ascending_order: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the certificates registered in your AWS account. The results are paginated with a default page size of 25. You can use the returned marker to retrieve additional results.

    Args:
        page_size(int, optional): The result page size. Defaults to None.
        marker(str, optional): The marker for the next set of results. Defaults to None.
        ascending_order(bool, optional): Specifies the order for results. If True, the results are returned in ascending order, based on the creation date. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_certificates",
        op_kwargs={
            "pageSize": page_size,
            "marker": marker,
            "ascendingOrder": ascending_order,
        },
    )


async def register(
    hub,
    ctx,
    certificate_pem: str,
    ca_certificate_pem: str = None,
    set_as_active: bool = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a device certificate with AWS IoT. If you have more than one CA certificate that has the same subject field, you must specify the CA certificate that was used to sign the device certificate being registered.

    Args:
        certificate_pem(str): The certificate data, in PEM format.
        ca_certificate_pem(str, optional): The CA certificate used to sign the device certificate being registered. Defaults to None.
        set_as_active(bool, optional): A boolean value that specifies if the certificate is set to active. Defaults to None.
        status(str, optional): The status of the register certificate request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.register(ctx, certificate_pem=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.register certificate_pem=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="register_certificate",
        op_kwargs={
            "certificatePem": certificate_pem,
            "caCertificatePem": ca_certificate_pem,
            "setAsActive": set_as_active,
            "status": status,
        },
    )


async def transfer(
    hub, ctx, certificate_id: str, target_aws_account: str, transfer_message: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Transfers the specified certificate to the specified AWS account. You can cancel the transfer until it is acknowledged by the recipient. No notification is sent to the transfer destination's account. It is up to the caller to notify the transfer target. The certificate being transferred must not be in the ACTIVE state. You can use the UpdateCertificate API to deactivate it. The certificate must not have any policies attached to it. You can use the DetachPrincipalPolicy API to detach them.

    Args:
        certificate_id(str): The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.).
        target_aws_account(str): The AWS account.
        transfer_message(str, optional): The transfer message. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.transfer(
                ctx, certificate_id=value, target_aws_account=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.transfer certificate_id=value, target_aws_account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="transfer_certificate",
        op_kwargs={
            "certificateId": certificate_id,
            "targetAwsAccount": target_aws_account,
            "transferMessage": transfer_message,
        },
    )


async def update(hub, ctx, certificate_id: str, new_status: str) -> None:
    r"""
    **Autogenerated function**

    Updates the status of the specified certificate. This operation is idempotent. Certificates must be in the ACTIVE state to authenticate devices that use a certificate to connect to AWS IoT. Within a few minutes of updating a certificate from the ACTIVE state to any other state, AWS IoT disconnects all devices that used that certificate to connect. Devices cannot use a certificate that is not in the ACTIVE state to reconnect.

    Args:
        certificate_id(str): The ID of the certificate. (The last part of the certificate ARN contains the certificate ID.).
        new_status(str): The new status.  Note: Setting the status to PENDING_TRANSFER or PENDING_ACTIVATION will result in an exception being thrown. PENDING_TRANSFER and PENDING_ACTIVATION are statuses used internally by AWS IoT. They are not intended for developer use.  Note: The status value REGISTER_INACTIVE is deprecated and should not be used.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.init.update(
                ctx, certificate_id=value, new_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.init.update certificate_id=value, new_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_certificate",
        op_kwargs={"certificateId": certificate_id, "newStatus": new_status},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    bot_alias_name: str,
    bot_id: str,
    description: str = None,
    bot_version: str = None,
    bot_alias_locale_settings: Dict = None,
    conversation_log_settings: Dict = None,
    sentiment_analysis_settings: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alias for the specified version of a bot. Use an alias to enable you to change the version of a bot without updating applications that use the bot. For example, you can create an alias called "PROD" that your applications use to call the Amazon Lex bot.

    Args:
        bot_alias_name(str): The alias to create. The name must be unique for the bot.
        description(str, optional): A description of the alias. Use this description to help identify the alias. Defaults to None.
        bot_version(str, optional): The version of the bot that this alias points to. You can use the operation to change the bot version associated with the alias. Defaults to None.
        bot_alias_locale_settings(Dict, optional): Maps configuration information to a specific locale. You can use this parameter to specify a specific Lambda function to run different functions in different locales. Defaults to None.
        conversation_log_settings(Dict, optional): Specifies whether Amazon Lex logs text and audio for a conversation with the bot. When you enable conversation logs, text logs store text input, transcripts of audio input, and associated metadata in Amazon CloudWatch Logs. Audio logs store audio input in Amazon S3. Defaults to None.
        sentiment_analysis_settings(Dict, optional): Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances. Defaults to None.
        bot_id(str): The unique identifier of the bot that the alias applies to.
        tags(Dict, optional): A list of tags to add to the bot alias. You can only add tags when you create an alias, you can't use the UpdateBotAlias operation to update the tags on a bot alias. To update tags, use the TagResource operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.alias.create(
                ctx, bot_alias_name=value, bot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.alias.create bot_alias_name=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_bot_alias",
        op_kwargs={
            "botAliasName": bot_alias_name,
            "description": description,
            "botVersion": bot_version,
            "botAliasLocaleSettings": bot_alias_locale_settings,
            "conversationLogSettings": conversation_log_settings,
            "sentimentAnalysisSettings": sentiment_analysis_settings,
            "botId": bot_id,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, bot_alias_id: str, bot_id: str, skip_resource_in_use_check: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified bot alias.

    Args:
        bot_alias_id(str): The unique identifier of the bot alias to delete.
        bot_id(str): The unique identifier of the bot associated with the alias to delete.
        skip_resource_in_use_check(bool, optional): When this parameter is true, Amazon Lex doesn't check to see if any other resource is using the alias before it is deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.alias.delete(
                ctx, bot_alias_id=value, bot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.alias.delete bot_alias_id=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_bot_alias",
        op_kwargs={
            "botAliasId": bot_alias_id,
            "botId": bot_id,
            "skipResourceInUseCheck": skip_resource_in_use_check,
        },
    )


async def describe(hub, ctx, bot_alias_id: str, bot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get information about a specific bot alias.

    Args:
        bot_alias_id(str): The identifier of the bot alias to describe.
        bot_id(str): The identifier of the bot associated with the bot alias to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.alias.describe(
                ctx, bot_alias_id=value, bot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.alias.describe bot_alias_id=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_bot_alias",
        op_kwargs={"botAliasId": bot_alias_id, "botId": bot_id},
    )


async def update(
    hub,
    ctx,
    bot_alias_id: str,
    bot_alias_name: str,
    bot_id: str,
    description: str = None,
    bot_version: str = None,
    bot_alias_locale_settings: Dict = None,
    conversation_log_settings: Dict = None,
    sentiment_analysis_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of an existing bot alias.

    Args:
        bot_alias_id(str): The unique identifier of the bot alias.
        bot_alias_name(str): The new name to assign to the bot alias.
        description(str, optional): The new description to assign to the bot alias. Defaults to None.
        bot_version(str, optional): The new bot version to assign to the bot alias. Defaults to None.
        bot_alias_locale_settings(Dict, optional): The new Lambda functions to use in each locale for the bot alias. Defaults to None.
        conversation_log_settings(Dict, optional): The new settings for storing conversation logs in Amazon CloudWatch Logs and Amazon S3 buckets. Defaults to None.
        sentiment_analysis_settings(Dict, optional): Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances. Defaults to None.
        bot_id(str): The identifier of the bot with the updated alias.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.alias.update(
                ctx, bot_alias_id=value, bot_alias_name=value, bot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.alias.update bot_alias_id=value, bot_alias_name=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_bot_alias",
        op_kwargs={
            "botAliasId": bot_alias_id,
            "botAliasName": bot_alias_name,
            "description": description,
            "botVersion": bot_version,
            "botAliasLocaleSettings": bot_alias_locale_settings,
            "conversationLogSettings": conversation_log_settings,
            "sentimentAnalysisSettings": sentiment_analysis_settings,
            "botId": bot_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    file_system_type: str,
    storage_capacity: int,
    subnet_ids: List,
    client_request_token: str = None,
    storage_type: str = None,
    security_group_ids: List = None,
    tags: List = None,
    kms_key_id: str = None,
    windows_configuration: Dict = None,
    lustre_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new, empty Amazon FSx file system. If a file system with the specified client request token exists and the parameters match, CreateFileSystem returns the description of the existing file system. If a file system specified client request token exists and the parameters don't match, this call returns IncompatibleParameterError. If a file system with the specified client request token doesn't exist, CreateFileSystem does the following:    Creates a new, empty Amazon FSx file system with an assigned ID, and an initial lifecycle state of CREATING.   Returns the description of the file system.   This operation requires a client request token in the request that Amazon FSx uses to ensure idempotent creation. This means that calling the operation multiple times with the same client request token has no effect. By using the idempotent operation, you can retry a CreateFileSystem operation without the risk of creating an extra file system. This approach can be useful when an initial call fails in a way that makes it unclear whether a file system was created. Examples are if a transport level timeout occurred, or your connection was reset. If you use the same client request token and the initial call created a file system, the client receives success as long as the parameters are the same.  The CreateFileSystem call returns while the file system's lifecycle state is still CREATING. You can check the file-system creation status by calling the DescribeFileSystems operation, which returns the file system state along with other information.

    Args:
        client_request_token(str, optional): A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent creation. This string is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        file_system_type(str): The type of Amazon FSx file system to create, either WINDOWS or LUSTRE.
        storage_capacity(int): Sets the storage capacity of the file system that you're creating. For Lustre file systems:   For SCRATCH_2 and PERSISTENT_1 SSD deployment types, valid values are 1200 GiB, 2400 GiB, and increments of 2400 GiB.   For PERSISTENT HDD file systems, valid values are increments of 6000 GiB for 12 MB/s/TiB file systems and increments of 1800 GiB for 40 MB/s/TiB file systems.   For SCRATCH_1 deployment type, valid values are 1200 GiB, 2400 GiB, and increments of 3600 GiB.   For Windows file systems:   If StorageType=SSD, valid values are 32 GiB - 65,536 GiB (64 TiB).   If StorageType=HDD, valid values are 2000 GiB - 65,536 GiB (64 TiB).  .
        storage_type(str, optional): Sets the storage type for the file system you're creating. Valid values are SSD and HDD.   Set to SSD to use solid state drive storage. SSD is supported on all Windows and Lustre deployment types.   Set to HDD to use hard disk drive storage. HDD is supported on SINGLE_AZ_2 and MULTI_AZ_1 Windows file system deployment types, and on PERSISTENT Lustre file system deployment types.     Default value is SSD. For more information, see  Storage Type Options in the Amazon FSx for Windows User Guide and Multiple Storage Options in the Amazon FSx for Lustre User Guide. . Defaults to None.
        subnet_ids(List): Specifies the IDs of the subnets that the file system will be accessible from. For Windows MULTI_AZ_1 file system deployment types, provide exactly two subnet IDs, one for the preferred file server and one for the standby file server. You specify one of these subnets as the preferred subnet using the WindowsConfiguration > PreferredSubnetID property. For more information, see  Availability and durability: Single-AZ and Multi-AZ file systems. For Windows SINGLE_AZ_1 and SINGLE_AZ_2 file system deployment types and Lustre file systems, provide exactly one subnet ID. The file server is launched in that subnet's Availability Zone.
        security_group_ids(List, optional): A list of IDs specifying the security groups to apply to all network interfaces created for file system access. This list isn't returned in later requests to describe the file system. Defaults to None.
        tags(List, optional): The tags to apply to the file system being created. The key value of the Name tag appears in the console as the file system name. Defaults to None.
        kms_key_id(str, optional): The ID of the AWS Key Management Service (AWS KMS) key used to encrypt the file system's data for Amazon FSx for Windows File Server file systems and Amazon FSx for Lustre PERSISTENT_1 file systems at rest. In either case, if not specified, the Amazon FSx managed key is used. The Amazon FSx for Lustre SCRATCH_1 and SCRATCH_2 file systems are always encrypted at rest using Amazon FSx managed keys. For more information, see Encrypt in the AWS Key Management Service API Reference. Defaults to None.
        windows_configuration(Dict, optional): The Microsoft Windows configuration for the file system being created. . Defaults to None.
        lustre_configuration(Dict, optional): The Lustre configuration for the file system being created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.init.create(
                ctx, file_system_type=value, storage_capacity=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.init.create file_system_type=value, storage_capacity=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="create_file_system",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "FileSystemType": file_system_type,
            "StorageCapacity": storage_capacity,
            "StorageType": storage_type,
            "SubnetIds": subnet_ids,
            "SecurityGroupIds": security_group_ids,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "WindowsConfiguration": windows_configuration,
            "LustreConfiguration": lustre_configuration,
        },
    )


async def delete(
    hub,
    ctx,
    file_system_id: str,
    client_request_token: str = None,
    windows_configuration: Dict = None,
    lustre_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a file system, deleting its contents. After deletion, the file system no longer exists, and its data is gone. Any existing automatic backups will also be deleted. By default, when you delete an Amazon FSx for Windows File Server file system, a final backup is created upon deletion. This final backup is not subject to the file system's retention policy, and must be manually deleted. The DeleteFileSystem action returns while the file system has the DELETING status. You can check the file system deletion status by calling the DescribeFileSystems action, which returns a list of file systems in your account. If you pass the file system ID for a deleted file system, the DescribeFileSystems returns a FileSystemNotFound error.  Deleting an Amazon FSx for Lustre file system will fail with a 400 BadRequest if a data repository task is in a PENDING or EXECUTING state.   The data in a deleted file system is also deleted and can't be recovered by any means.

    Args:
        file_system_id(str): The ID of the file system you want to delete.
        client_request_token(str, optional): A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent deletion. This is automatically filled on your behalf when using the AWS CLI or SDK. Defaults to None.
        windows_configuration(Dict, optional): The configuration object for the Microsoft Windows file system used in the DeleteFileSystem operation. Defaults to None.
        lustre_configuration(Dict, optional): The configuration object for the Amazon FSx for Lustre file system being deleted in the DeleteFileSystem operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.init.delete(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.init.delete file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="delete_file_system",
        op_kwargs={
            "FileSystemId": file_system_id,
            "ClientRequestToken": client_request_token,
            "WindowsConfiguration": windows_configuration,
            "LustreConfiguration": lustre_configuration,
        },
    )


async def describe_all(
    hub,
    ctx,
    file_system_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of specific Amazon FSx file systems, if a FileSystemIds value is provided for that file system. Otherwise, it returns descriptions of all file systems owned by your AWS account in the AWS Region of the endpoint that you're calling. When retrieving all file system descriptions, you can optionally specify the MaxResults parameter to limit the number of descriptions in a response. If more file system descriptions remain, Amazon FSx returns a NextToken value in the response. In this case, send a later request with the NextToken request parameter set to the value of NextToken from the last response. This action is used in an iterative process to retrieve a list of your file system descriptions. DescribeFileSystems is called first without a NextTokenvalue. Then the action continues to be called with the NextToken parameter set to the value of the last NextToken value until a response has no NextToken. When using this action, keep the following in mind:   The implementation might return fewer than MaxResults file system descriptions while still including a NextToken value.   The order of file systems returned in the response of one DescribeFileSystems call and the order of file systems returned across the responses of a multicall iteration is unspecified.

    Args:
        file_system_ids(List, optional): IDs of the file systems whose descriptions you want to retrieve (String). Defaults to None.
        max_results(int, optional): Maximum number of file systems to return in the response (integer). This parameter value must be greater than 0. The number of items that Amazon FSx returns is the minimum of the MaxResults parameter specified in the request and the service's internal maximum number of items per page. Defaults to None.
        next_token(str, optional): Opaque pagination token returned from a previous DescribeFileSystems operation (String). If a token present, the action continues the list from where the returning call left off. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="describe_file_systems",
        op_kwargs={
            "FileSystemIds": file_system_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    file_system_id: str,
    client_request_token: str = None,
    storage_capacity: int = None,
    windows_configuration: Dict = None,
    lustre_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to update the configuration of an existing Amazon FSx file system. You can update multiple properties in a single request. For Amazon FSx for Windows File Server file systems, you can update the following properties:   AuditLogConfiguration   AutomaticBackupRetentionDays   DailyAutomaticBackupStartTime   SelfManagedActiveDirectoryConfiguration   StorageCapacity   ThroughputCapacity   WeeklyMaintenanceStartTime   For Amazon FSx for Lustre file systems, you can update the following properties:   AutoImportPolicy   AutomaticBackupRetentionDays   DailyAutomaticBackupStartTime   DataCompressionType   StorageCapacity   WeeklyMaintenanceStartTime

    Args:
        file_system_id(str): Identifies the file system that you are updating.
        client_request_token(str, optional): A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent updates. This string is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        storage_capacity(int, optional): Use this parameter to increase the storage capacity of an Amazon FSx file system. Specifies the storage capacity target value, GiB, to increase the storage capacity for the file system that you're updating. You cannot make a storage capacity increase request if there is an existing storage capacity increase request in progress. For Windows file systems, the storage capacity target value must be at least 10 percent (%) greater than the current storage capacity value. In order to increase storage capacity, the file system must have at least 16 MB/s of throughput capacity. For Lustre file systems, the storage capacity target value can be the following:   For SCRATCH_2 and PERSISTENT_1 SSD deployment types, valid values are in multiples of 2400 GiB. The value must be greater than the current storage capacity.   For PERSISTENT HDD file systems, valid values are multiples of 6000 GiB for 12 MB/s/TiB file systems and multiples of 1800 GiB for 40 MB/s/TiB file systems. The values must be greater than the current storage capacity.   For SCRATCH_1 file systems, you cannot increase the storage capacity.   For more information, see Managing storage capacity in the Amazon FSx for Windows File Server User Guide and Managing storage and throughput capacity in the Amazon FSx for Lustre User Guide. Defaults to None.
        windows_configuration(Dict, optional): The configuration updates for an Amazon FSx for Windows File Server file system. Defaults to None.
        lustre_configuration(Dict, optional): The configuration object for Amazon FSx for Lustre file systems used in the UpdateFileSystem operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.init.update(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.init.update file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="update_file_system",
        op_kwargs={
            "FileSystemId": file_system_id,
            "ClientRequestToken": client_request_token,
            "StorageCapacity": storage_capacity,
            "WindowsConfiguration": windows_configuration,
            "LustreConfiguration": lustre_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    hosted_zone_id: str,
    traffic_policy_instance_name_marker: str = None,
    traffic_policy_instance_type_marker: str = None,
    max_items: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the traffic policy instances that you created in a specified hosted zone.  After you submit a CreateTrafficPolicyInstance or an UpdateTrafficPolicyInstance request, there's a brief delay while Amazon Route 53 creates the resource record sets that are specified in the traffic policy definition. For more information, see the State response element.  Route 53 returns a maximum of 100 items in each response. If you have a lot of traffic policy instances, you can use the MaxItems parameter to list them in groups of up to 100.

    Args:
        hosted_zone_id(str): The ID of the hosted zone that you want to list traffic policy instances for.
        traffic_policy_instance_name_marker(str, optional): If the value of IsTruncated in the previous response is true, you have more traffic policy instances. To get more traffic policy instances, submit another ListTrafficPolicyInstances request. For the value of trafficpolicyinstancename, specify the value of TrafficPolicyInstanceNameMarker from the previous response, which is the name of the first traffic policy instance in the next group of traffic policy instances. If the value of IsTruncated in the previous response was false, there are no more traffic policy instances to get. Defaults to None.
        traffic_policy_instance_type_marker(str, optional): If the value of IsTruncated in the previous response is true, you have more traffic policy instances. To get more traffic policy instances, submit another ListTrafficPolicyInstances request. For the value of trafficpolicyinstancetype, specify the value of TrafficPolicyInstanceTypeMarker from the previous response, which is the type of the first traffic policy instance in the next group of traffic policy instances. If the value of IsTruncated in the previous response was false, there are no more traffic policy instances to get. Defaults to None.
        max_items(str, optional): The maximum number of traffic policy instances to be included in the response body for this request. If you have more than MaxItems traffic policy instances, the value of the IsTruncated element in the response is true, and the values of HostedZoneIdMarker, TrafficPolicyInstanceNameMarker, and TrafficPolicyInstanceTypeMarker represent the first traffic policy instance that Amazon Route 53 will return if you submit another request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.traffic_policy.instance.by.hosted_zone.list(
                ctx, hosted_zone_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.traffic_policy.instance.by.hosted_zone.list hosted_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_traffic_policy_instances_by_hosted_zone",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "TrafficPolicyInstanceNameMarker": traffic_policy_instance_name_marker,
            "TrafficPolicyInstanceTypeMarker": traffic_policy_instance_type_marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def complete(hub, ctx, replication_group_id: str, force: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Complete the migration of data.

    Args:
        replication_group_id(str): The ID of the replication group to which data is being migrated.
        force(bool, optional): Forces the migration to stop without ensuring that data is in sync. It is recommended to use this option only to abort the migration and not recommended when application wants to continue migration to ElastiCache. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.migration.complete(ctx, replication_group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.migration.complete replication_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="complete_migration",
        op_kwargs={"ReplicationGroupId": replication_group_id, "Force": force},
    )


async def start(
    hub, ctx, replication_group_id: str, customer_node_endpoint_list: List
) -> Dict:
    r"""
    **Autogenerated function**

    Start the migration of data.

    Args:
        replication_group_id(str): The ID of the replication group to which data should be migrated.
        customer_node_endpoint_list(List): List of endpoints from which data should be migrated. For Redis (cluster mode disabled), list should have only one element.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.migration.start(
                ctx, replication_group_id=value, customer_node_endpoint_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.migration.start replication_group_id=value, customer_node_endpoint_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="start_migration",
        op_kwargs={
            "ReplicationGroupId": replication_group_id,
            "CustomerNodeEndpointList": customer_node_endpoint_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, s3_source_config: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a selection of sample records from an Amazon S3 datasource.

    Args:
        s3_source_config(Dict, optional): A datasource bucket in Amazon S3. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.sample_data.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.sample_data.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="get_sample_data",
        op_kwargs={"S3SourceConfig": s3_source_config},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Add tags to a MediaConvert queue, preset, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html

    Args:
        arn(str): The Amazon Resource Name (ARN) of the resource that you want to tag. To get the ARN, send a GET request with the resource name.
        tags(Dict): The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.resource.tag(ctx, arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.resource.tag arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="tag_resource",
        op_kwargs={"Arn": arn, "Tags": tags},
    )


async def untag(hub, ctx, arn: str, tag_keys: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Remove tags from a MediaConvert queue, preset, or job template. For information about tagging, see the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/tagging-resources.html

    Args:
        arn(str): The Amazon Resource Name (ARN) of the resource that you want to remove tags from. To get the ARN, send a GET request with the resource name.
        tag_keys(List, optional): The keys of the tags that you want to remove from the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.resource.untag(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.resource.untag arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="untag_resource",
        op_kwargs={"Arn": arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(
    hub, ctx, text: str, language_code: str = None, endpoint_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Inspects text for named entities, and returns information about them. For more information, about named entities, see how-entities.

    Args:
        text(str): A UTF-8 text string. Each string must contain fewer that 5,000 bytes of UTF-8 encoded characters.
        language_code(str, optional): The language of the input documents. You can specify any of the primary languages supported by Amazon Comprehend. All documents must be in the same language. If your request includes the endpoint for a custom entity recognition model, Amazon Comprehend uses the language of your custom model, and it ignores any language code that you specify here. Defaults to None.
        endpoint_arn(str, optional): The Amazon Resource Name of an endpoint that is associated with a custom entity recognition model. Provide an endpoint if you want to detect entities by using your own custom model instead of the default model that is used by Amazon Comprehend. If you specify an endpoint, Amazon Comprehend uses the language of your custom model, and it ignores any language code that you provide in your request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.init.detect(ctx, text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.init.detect text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="detect_entities",
        op_kwargs={
            "Text": text,
            "LanguageCode": language_code,
            "EndpointArn": endpoint_arn,
        },
    )
